==> jc-1.4.0.tar.gz: java/rmi/ServerError.h <==
// public class java.rmi.ServerError

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 512cf355dcdeb26d java_rmi_RemoteException
// @dep_class e98645cb75914910 java_rmi_ServerError

// header file dependencies
// @dep_header java_rmi_RemoteException

#include "java/rmi/RemoteException.h"

#ifndef _JC_java_rmi_ServerError_H_
#define _JC_java_rmi_ServerError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Error$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_ServerError$sub_refs	_jc_java_rmi_ServerError$sub_refs;
typedef struct _jc_java_rmi_ServerError$sub_nonrefs	_jc_java_rmi_ServerError$sub_nonrefs;
typedef struct _jc_java_rmi_ServerError$refs	_jc_java_rmi_ServerError$refs;
typedef struct _jc_java_rmi_ServerError$nonrefs	_jc_java_rmi_ServerError$nonrefs;
typedef struct _jc_java_rmi_ServerError$object	_jc_java_rmi_ServerError$object;

typedef struct _jc_java_rmi_ServerError$fields_struct	_jc_java_rmi_ServerError$fields_struct;
typedef const struct _jc_java_rmi_ServerError$vmethods	_jc_java_rmi_ServerError$vmethods;
typedef const struct _jc_java_rmi_ServerError$vtable	_jc_java_rmi_ServerError$vtable;
typedef const struct _jc_java_rmi_ServerError$vtype	_jc_java_rmi_ServerError$vtype;

// Class fields structure
struct _jc_java_rmi_ServerError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_ServerError$fields_struct _jc_java_rmi_ServerError$class_fields;

// Constructors
extern void _jc_java_rmi_ServerError$method$_init$3c8a86b607193f44(_jc_env *, struct _jc_java_rmi_ServerError$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Error$object *);

// Virtual methods structure
struct _jc_java_rmi_ServerError$vmethods {
};

// Vtable
struct _jc_java_rmi_ServerError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_rmi_RemoteException$vmethods	java_rmi_RemoteException;
	_jc_java_rmi_ServerError$vmethods	java_rmi_ServerError;
};

// Vtype
struct _jc_java_rmi_ServerError$vtype {
	_jc_type			type;
	_jc_java_rmi_ServerError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_ServerError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_ServerError$refs {
    _jc_java_rmi_ServerError$sub_refs	java_rmi_ServerError;
    _jc_java_rmi_RemoteException$sub_refs	java_rmi_RemoteException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_ServerError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_ServerError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_rmi_RemoteException$sub_nonrefs	java_rmi_RemoteException;
    _jc_java_rmi_ServerError$sub_nonrefs	java_rmi_ServerError;
};

// Object instance structure
struct _jc_java_rmi_ServerError$object {
	_jc_java_rmi_ServerError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_ServerError$vtype	*vtype;
	_jc_java_rmi_ServerError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_ServerError$vtype _jc_java_rmi_ServerError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_ServerError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_ServerError$class_object;

#endif	/* _JC_java_rmi_ServerError_H_ */

==> jc-1.4.6.tar.gz: java/rmi/ServerError.h <==
// public class java.rmi.ServerError

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 512cf355dcdeb26d java_rmi_RemoteException
// @dep_class e98645cb75914910 java_rmi_ServerError

// header file dependencies
// @dep_header java_rmi_RemoteException

#include "java/rmi/RemoteException.h"

#ifndef _JC_java_rmi_ServerError_H_
#define _JC_java_rmi_ServerError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Error$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_ServerError$sub_refs	_jc_java_rmi_ServerError$sub_refs;
typedef struct _jc_java_rmi_ServerError$sub_nonrefs	_jc_java_rmi_ServerError$sub_nonrefs;
typedef struct _jc_java_rmi_ServerError$refs	_jc_java_rmi_ServerError$refs;
typedef struct _jc_java_rmi_ServerError$nonrefs	_jc_java_rmi_ServerError$nonrefs;
typedef struct _jc_java_rmi_ServerError$object	_jc_java_rmi_ServerError$object;

typedef struct _jc_java_rmi_ServerError$fields_struct	_jc_java_rmi_ServerError$fields_struct;
typedef const struct _jc_java_rmi_ServerError$vmethods	_jc_java_rmi_ServerError$vmethods;
typedef const struct _jc_java_rmi_ServerError$vtable	_jc_java_rmi_ServerError$vtable;
typedef const struct _jc_java_rmi_ServerError$vtype	_jc_java_rmi_ServerError$vtype;

// Class fields structure
struct _jc_java_rmi_ServerError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_ServerError$fields_struct _jc_java_rmi_ServerError$class_fields;

// Constructors
extern void _jc_java_rmi_ServerError$method$_init$3c8a86b607193f44(_jc_env *, struct _jc_java_rmi_ServerError$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Error$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_ServerError$vmethods {
};

// Vtable
struct _jc_java_rmi_ServerError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_rmi_RemoteException$vmethods	java_rmi_RemoteException;
	_jc_java_rmi_ServerError$vmethods	java_rmi_ServerError;
};

// Vtype
struct _jc_java_rmi_ServerError$vtype {
	_jc_type			type;
	_jc_java_rmi_ServerError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_ServerError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_ServerError$refs {
    _jc_java_rmi_ServerError$sub_refs	java_rmi_ServerError;
    _jc_java_rmi_RemoteException$sub_refs	java_rmi_RemoteException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_ServerError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_ServerError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_rmi_RemoteException$sub_nonrefs	java_rmi_RemoteException;
    _jc_java_rmi_ServerError$sub_nonrefs	java_rmi_ServerError;
};

// Object instance structure
struct _jc_java_rmi_ServerError$object {
	_jc_java_rmi_ServerError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_ServerError$vtype	*vtype;
	_jc_java_rmi_ServerError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_ServerError$vtype _jc_java_rmi_ServerError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_ServerError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_ServerError$class_object;

#endif	/* _JC_java_rmi_ServerError_H_ */
